# [unsee.cc](https://unsee.cc) downloader

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![PyPI](https://img.shields.io/pypi/v/unsee-dl.svg)](https://pypi.org/project/unsee-dl/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/unsee-dl.svg)](https://pypi.org/project/unsee-dl/)

# Usage

Requires [Mozilla Firefox](https://www.mozilla.org/it/firefox/) and [geckodriver](https://github.com/mozilla/geckodriver).

```
pip install unsee-dl

unsee-dl [-o OUT_DIR] <id...>
```
